﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;
using HeuristicLab.Services.Hive.DataAccess;
using HeuristicLab.Services.Hive;
using HeuristicLab.Services.Hive.Common.DataTransfer;
using System.Text;

public partial class Status : System.Web.UI.Page {
  protected void Page_Load(object sender, EventArgs e) {
    var dao = ServiceLocator.Instance.HiveDao;
    var onlineSlaves = dao.GetSlaves(x => x.SlaveState == SlaveState.Calculating || x.SlaveState == SlaveState.Idle);

    int availableCores = onlineSlaves.Sum(s => s.Cores.Value);
    int usedCores = availableCores - onlineSlaves.Sum(s => s.FreeCores.Value);
    int jobCount = ServiceLocator.Instance.HiveDao.GetJobs(x => x.State == JobState.Waiting).Count();

    this.availableCoresLabel.Text = availableCores.ToString();
    this.usedCoresLabel.Text = usedCores.ToString();
    this.waitingJobsLabel.Text = jobCount.ToString();

    slavesLabel.Text = string.Join(", ", onlineSlaves.Select(x => x.Name));

    var stats = dao.GetStatistics(x => x.Timestamp >= DateTime.Now.Subtract(TimeSpan.FromDays(7))).OrderByDescending(x => x.TimeStamp);
    var sb = new StringBuilder();
    int i = 0;
    foreach (var s in stats) {
      if (i % 60 == 0) { // just ~1 per hour
        var cores = s.SlaveStatistics.Sum(x => x.Cores);
        var usdCores = cores - s.SlaveStatistics.Sum(x => x.FreeCores);
        var execTime = new TimeSpan(s.UserStatistics.Sum(x => x.ExecutionTime.Ticks));
        sb.AppendLine(string.Format("{0}: Cores: {1}, UsedCores: {2}, TotalExecutionTime: {3}<br/>", s.TimeStamp.ToString(), cores, usdCores, execTime.ToString()));
      }
      i++;
    }
    statisticsLabel.Text = sb.ToString();
  }
}